- timeAndSeries
A data frame containing the timestamp and
corresponding series data.
- timeWindow
The time window for analysis.
- transfType
The transformation type for non-stationary EVA.
It can be one of the following:
trend
Long-term variations of the timeseries
seasonal
Long-term and seasonal variations of extremes
trendCIPercentile
Long-term variations of extremes using
a specified percentile
trendPeaks
Long-term variations of the peaks
minPeakDistanceInDays
The minimum peak distance in days.
seasonalityVar
A logical value indicating whether to consider
seasonality in the analysis.
minEventsPerYear
The minimum number of events per year.
gevMaxima
The type of maxima for the GEV distribution
(annual or monthly, default is annual).
ciPercentile
The percentile value for confidence intervals.
gevType
The type of GEV distribution (GEV or GPD).
evdType
The type of extreme value distribution (GEV or GPD).
tail
The mode of the analysis
(e.g., high for flood peaks or low for drought peaks).
epy
The average number of events per year, can be specified by the
user or automatically set according to the tail selected.
lowdt
The temporal resolultion used for low values. default is 7 days.
trans
The transformation used to fit the EVD. Can be:
ori
use of original data
rev
Reversing the data (used for low extremes)
inv
inversing the data (used for low extreme, can lead to unstabilities)
lninv
log of inverse the data (used for low extreme, under development)
TrendTh
The threshold used to compute the trend on extreme events
(only valid if transftype==trendPeaks). If not specified, the optimal
threshold is identified within the function