Learn R Programming

RtsEva (version 1.1.0)

tsEvaComputeReturnPeriodsGEV: tsEvaComputeReturnPeriodsGEV

Description

tsEvaComputeReturnPeriodsGEVis a function that computes the return periods of a set of observations (can be Annual maxima or others) for a Generalized Extreme Value (GEV) distribution, given the GEV parameters and their standard error. The return levels represent the values of annual maxima with a certain probability, while the return periods indicate the average time between exceedances of those threshold values.

Usage

tsEvaComputeReturnPeriodsGEV(epsilon, sigma, mu, BlockMax)

Value

A list containing the following components:

GevPseudo

A matrix of pseudo observations obtained from the GEV distribution for each annual extreme at every time step.

returnPeriods

A matrix of return periods corresponding to the pseudo observations.

PseudoObs

The pseudo observation corresponding to the maximum value used in the computation.

Arguments

epsilon

The shape parameter of the GEV distribution.

sigma

The scale parameter of the GEV distribution.

mu

The location parameter of the GEV distribution.

BlockMax

A vector containing the block maxima data.

See Also

empdis

Examples

Run this code

# Example usage with some sample data
epsilon <- 0.1
sigma <- 2.2
mu <- 1.3
BlockMax <- c(10, 20, 30, 40, 50)

results <- tsEvaComputeReturnPeriodsGEV(epsilon, sigma, mu, BlockMax)
head(results$GevPseudo)
head(results$returnPeriods)
head(results$PseudoObs)

Run the code above in your browser using DataLab