tsEvaNanRunnigBlowTh: Calculate the return period of low flow based on a threshold and window size
Description
This function calculates the return period of low flow for a given time series
based on a threshold and window size. It uses a sliding window approach to
count the number of values below the threshold within each window, and then
calculates the return period based on the proportion of values below the
threshold. Assumes that the input data has a 7 days timestep.
A data frame with two columns: "time" representing the time points
corresponding to the sliding windows, and "RP" representing the
calculated return period of low flow.