tsEvaNanRunningMean: Calculate the running mean of a time series with NaN handling
Description
This function calculates the running mean of a time series, taking into account NaN values.
It uses a sliding window approach to calculate the mean, where the window size is specified by the user.
If the number of non-NaN values within the window is greater than a threshold, the mean is calculated.
Otherwise, NaN is returned.
Usage
tsEvaNanRunningMean(series, windowSize)
Value
A vector containing the running mean of the time series