computeAnnualMaxima is a function that computes the annual maxima of
a time series.
Usage
computeAnnualMaxima(timeAndSeries)
Value
A list containing the annual maximum values, their corresponding dates,
and their indices.
annualMax
A numeric vector of annual maximum values.
annualMaxDate
A vector of dates corresponding to the annual
maximum values.
annualMaxIndx
A vector of indices indicating the positions
of the annual maximum values in the original time series.
Arguments
timeAndSeries
A matrix or data frame containing the time stamps and
series values. The first column should contain the time stamps and the
second column should contain the series values.